nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Fifointenclr

Struct Fifointenclr 

#[repr(transparent)]
pub struct Fifointenclr(pub u32);
FIFO interrupt enable clear (disable) and read register.

Tuple Fields

0: u32

Implementations

Source

impl Fifointenclr

pub const fn txerr(&self) -> bool

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn set_txerr(&mut self, val: bool)

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn rxerr(&self) -> bool

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn set_rxerr(&mut self, val: bool)

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn txlvl(&self) -> bool

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn set_txlvl(&mut self, val: bool)

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn rxlvl(&self) -> bool

Writing one clears the corresponding bits in the FIFOINTENSET register.

pub const fn set_rxlvl(&mut self, val: bool)

Writing one clears the corresponding bits in the FIFOINTENSET register.