nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Intenset

Struct Intenset 

#[repr(transparent)]
pub struct Intenset(pub u32);
Interrupt Enable read and Set register for USART (not FIFO) status. Contains individual interrupt enable bits for each potential USART interrupt. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.

Tuple Fields

0: u32

Implementations

Source

impl Intenset

pub const fn txidleen(&self) -> bool

When 1, enables an interrupt when the transmitter becomes idle (TXIDLE = 1).

pub const fn set_txidleen(&mut self, val: bool)

When 1, enables an interrupt when the transmitter becomes idle (TXIDLE = 1).

pub const fn deltactsen(&self) -> bool

When 1, enables an interrupt when there is a change in the state of the CTS input.

pub const fn set_deltactsen(&mut self, val: bool)

When 1, enables an interrupt when there is a change in the state of the CTS input.

pub const fn txdisen(&self) -> bool

When 1, enables an interrupt when the transmitter is fully disabled as indicated by the TXDISINT flag in STAT. See description of the TXDISINT bit for details.

pub const fn set_txdisen(&mut self, val: bool)

When 1, enables an interrupt when the transmitter is fully disabled as indicated by the TXDISINT flag in STAT. See description of the TXDISINT bit for details.

pub const fn deltarxbrken(&self) -> bool

When 1, enables an interrupt when a change of state has occurred in the detection of a received break condition (break condition asserted or deasserted).

pub const fn set_deltarxbrken(&mut self, val: bool)

When 1, enables an interrupt when a change of state has occurred in the detection of a received break condition (break condition asserted or deasserted).

pub const fn starten(&self) -> bool

When 1, enables an interrupt when a received start bit has been detected.

pub const fn set_starten(&mut self, val: bool)

When 1, enables an interrupt when a received start bit has been detected.

pub const fn framerren(&self) -> bool

When 1, enables an interrupt when a framing error has been detected.

pub const fn set_framerren(&mut self, val: bool)

When 1, enables an interrupt when a framing error has been detected.

pub const fn parityerren(&self) -> bool

When 1, enables an interrupt when a parity error has been detected.

pub const fn set_parityerren(&mut self, val: bool)

When 1, enables an interrupt when a parity error has been detected.

pub const fn rxnoiseen(&self) -> bool

When 1, enables an interrupt when noise is detected. See description of the RXNOISEINT bit in Table 354.

pub const fn set_rxnoiseen(&mut self, val: bool)

When 1, enables an interrupt when noise is detected. See description of the RXNOISEINT bit in Table 354.

pub const fn aberren(&self) -> bool

When 1, enables an interrupt when an auto baud error occurs.

pub const fn set_aberren(&mut self, val: bool)

When 1, enables an interrupt when an auto baud error occurs.