#[repr(transparent)]pub struct Intstat(pub u32);Expand description
Interrupt status register. Reflects interrupts that are currently enabled.
Tuple Fields
0: u32Implementations
Sourceimpl Intstat
impl Intstat
Sourcepub const fn set_txidle(&mut self, val: bool)
pub const fn set_txidle(&mut self, val: bool)
Transmitter Idle status.
Sourcepub const fn deltacts(&self) -> bool
pub const fn deltacts(&self) -> bool
This bit is set when a change in the state of the CTS input is detected.
Sourcepub const fn set_deltacts(&mut self, val: bool)
pub const fn set_deltacts(&mut self, val: bool)
This bit is set when a change in the state of the CTS input is detected.
Sourcepub const fn set_txdisint(&mut self, val: bool)
pub const fn set_txdisint(&mut self, val: bool)
Transmitter Disabled Interrupt flag.
Sourcepub const fn deltarxbrk(&self) -> bool
pub const fn deltarxbrk(&self) -> bool
This bit is set when a change in the state of receiver break detection occurs.
Sourcepub const fn set_deltarxbrk(&mut self, val: bool)
pub const fn set_deltarxbrk(&mut self, val: bool)
This bit is set when a change in the state of receiver break detection occurs.
Sourcepub const fn start(&self) -> bool
pub const fn start(&self) -> bool
This bit is set when a start is detected on the receiver input.
Sourcepub const fn set_start(&mut self, val: bool)
pub const fn set_start(&mut self, val: bool)
This bit is set when a start is detected on the receiver input.
Sourcepub const fn framerrint(&self) -> bool
pub const fn framerrint(&self) -> bool
Framing Error interrupt flag.
Sourcepub const fn set_framerrint(&mut self, val: bool)
pub const fn set_framerrint(&mut self, val: bool)
Framing Error interrupt flag.
Sourcepub const fn parityerrint(&self) -> bool
pub const fn parityerrint(&self) -> bool
Parity Error interrupt flag.
Sourcepub const fn set_parityerrint(&mut self, val: bool)
pub const fn set_parityerrint(&mut self, val: bool)
Parity Error interrupt flag.
Sourcepub const fn rxnoiseint(&self) -> bool
pub const fn rxnoiseint(&self) -> bool
Received Noise interrupt flag.
Sourcepub const fn set_rxnoiseint(&mut self, val: bool)
pub const fn set_rxnoiseint(&mut self, val: bool)
Received Noise interrupt flag.
Sourcepub const fn set_aberrint(&mut self, val: bool)
pub const fn set_aberrint(&mut self, val: bool)
Auto baud Error Interrupt flag.