#[repr(transparent)]pub struct Fiford(pub u32);Expand description
FIFO read data.
Tuple Fields
0: u32Implementations
Sourceimpl Fiford
impl Fiford
Sourcepub const fn rxdata(&self) -> u16
pub const fn rxdata(&self) -> u16
Received data from the FIFO. The number of bits used depends on the DATALEN and PARITYSEL settings.
Sourcepub const fn set_rxdata(&mut self, val: u16)
pub const fn set_rxdata(&mut self, val: u16)
Received data from the FIFO. The number of bits used depends on the DATALEN and PARITYSEL settings.
Sourcepub const fn framerr(&self) -> bool
pub const fn framerr(&self) -> bool
Framing Error status flag. This bit reflects the status for the data it is read along with from the FIFO, and indicates that the character was received with a missing stop bit at the expected location. This could be an indication of a baud rate or configuration mismatch with the transmitting source.
Sourcepub const fn set_framerr(&mut self, val: bool)
pub const fn set_framerr(&mut self, val: bool)
Framing Error status flag. This bit reflects the status for the data it is read along with from the FIFO, and indicates that the character was received with a missing stop bit at the expected location. This could be an indication of a baud rate or configuration mismatch with the transmitting source.
Sourcepub const fn parityerr(&self) -> bool
pub const fn parityerr(&self) -> bool
Parity Error status flag. This bit reflects the status for the data it is read along with from the FIFO. This bit will be set when a parity error is detected in a received character.
Sourcepub const fn set_parityerr(&mut self, val: bool)
pub const fn set_parityerr(&mut self, val: bool)
Parity Error status flag. This bit reflects the status for the data it is read along with from the FIFO. This bit will be set when a parity error is detected in a received character.
Sourcepub const fn rxnoise(&self) -> bool
pub const fn rxnoise(&self) -> bool
Received Noise flag. See description of the RxNoiseInt bit in Table 354.
Sourcepub const fn set_rxnoise(&mut self, val: bool)
pub const fn set_rxnoise(&mut self, val: bool)
Received Noise flag. See description of the RxNoiseInt bit in Table 354.