#[repr(transparent)]pub struct Fifotrig(pub u32);Expand description
FIFO trigger settings for interrupt and DMA request.
Tuple Fields
0: u32Implementations
Sourceimpl Fifotrig
impl Fifotrig
Sourcepub const fn txlvlena(&self) -> bool
pub const fn txlvlena(&self) -> bool
Transmit FIFO level trigger enable. This trigger will become an interrupt if enabled in FIFOINTENSET, or a DMA trigger if DMATX in FIFOCFG is set.
Sourcepub const fn set_txlvlena(&mut self, val: bool)
pub const fn set_txlvlena(&mut self, val: bool)
Transmit FIFO level trigger enable. This trigger will become an interrupt if enabled in FIFOINTENSET, or a DMA trigger if DMATX in FIFOCFG is set.
Sourcepub const fn rxlvlena(&self) -> bool
pub const fn rxlvlena(&self) -> bool
Receive FIFO level trigger enable. This trigger will become an interrupt if enabled in FIFOINTENSET, or a DMA trigger if DMARX in FIFOCFG is set.
Sourcepub const fn set_rxlvlena(&mut self, val: bool)
pub const fn set_rxlvlena(&mut self, val: bool)
Receive FIFO level trigger enable. This trigger will become an interrupt if enabled in FIFOINTENSET, or a DMA trigger if DMARX in FIFOCFG is set.
Sourcepub const fn txlvl(&self) -> u8
pub const fn txlvl(&self) -> u8
Transmit FIFO level trigger point. This field is used only when TXLVLENA = 1. If enabled to do so, the FIFO level can wake up the device just enough to perform DMA, then return to the reduced power mode. See Hardware Wake-up control register. 0 = trigger when the TX FIFO becomes empty. 1 = trigger when the TX FIFO level decreases to one entry. 15 = trigger when the TX FIFO level decreases to 15 entries (is no longer full).
Sourcepub const fn set_txlvl(&mut self, val: u8)
pub const fn set_txlvl(&mut self, val: u8)
Transmit FIFO level trigger point. This field is used only when TXLVLENA = 1. If enabled to do so, the FIFO level can wake up the device just enough to perform DMA, then return to the reduced power mode. See Hardware Wake-up control register. 0 = trigger when the TX FIFO becomes empty. 1 = trigger when the TX FIFO level decreases to one entry. 15 = trigger when the TX FIFO level decreases to 15 entries (is no longer full).
Sourcepub const fn rxlvl(&self) -> u8
pub const fn rxlvl(&self) -> u8
Receive FIFO level trigger point. The RX FIFO level is checked when a new piece of data is received. This field is used only when RXLVLENA = 1. If enabled to do so, the FIFO level can wake up the device just enough to perform DMA, then return to the reduced power mode. See Hardware Wake-up control register. 0 = trigger when the RX FIFO has received one entry (is no longer empty). 1 = trigger when the RX FIFO has received two entries. 15 = trigger when the RX FIFO has received 16 entries (has become full).
Sourcepub const fn set_rxlvl(&mut self, val: u8)
pub const fn set_rxlvl(&mut self, val: u8)
Receive FIFO level trigger point. The RX FIFO level is checked when a new piece of data is received. This field is used only when RXLVLENA = 1. If enabled to do so, the FIFO level can wake up the device just enough to perform DMA, then return to the reduced power mode. See Hardware Wake-up control register. 0 = trigger when the RX FIFO has received one entry (is no longer empty). 1 = trigger when the RX FIFO has received two entries. 15 = trigger when the RX FIFO has received 16 entries (has become full).